@@ -99,7 +99,10 @@ class DateToHoliday(TransformPrimitive):
             df["date"] = df["date"].dt.date.astype("datetime64[ns]")
 
             df = df.merge(
-                holiday_df, how="left", left_on="date", right_on="holiday_date"
+                holiday_df,
+                how="left",
+                left_on="date",
+                right_on="holiday_date",
             )
             return df.names.values
 
@@ -122,7 +125,8 @@ class Day(TransformPrimitive):
     name = "day"
     input_types = [ColumnSchema(logical_type=Datetime)]
     return_type = ColumnSchema(
-        logical_type=Ordinal(order=list(range(1, 32))), semantic_tags={"category"}
+        logical_type=Ordinal(order=list(range(1, 32))),
+        semantic_tags={"category"},
     )
     compatibility = [Library.PANDAS, Library.DASK, Library.SPARK]
     description_template = "the day of the month of {}"
@@ -154,7 +158,8 @@ class DayOfYear(TransformPrimitive):
     name = "day_of_year"
     input_types = [ColumnSchema(logical_type=Datetime)]
     return_type = ColumnSchema(
-        logical_type=Ordinal(order=list(range(1, 367))), semantic_tags={"category"}
+        logical_type=Ordinal(order=list(range(1, 367))),
+        semantic_tags={"category"},
     )
     compatibility = [Library.PANDAS, Library.DASK, Library.SPARK]
     description_template = "the day of year from {}"
@@ -182,7 +187,8 @@ class DaysInMonth(TransformPrimitive):
     name = "days_in_month"
     input_types = [ColumnSchema(logical_type=Datetime)]
     return_type = ColumnSchema(
-        logical_type=Ordinal(order=list(range(1, 32))), semantic_tags={"category"}
+        logical_type=Ordinal(order=list(range(1, 32))),
+        semantic_tags={"category"},
     )
     compatibility = [Library.PANDAS, Library.DASK, Library.SPARK]
     description_template = "the days in the month of {}"
@@ -293,7 +299,8 @@ class Hour(TransformPrimitive):
     name = "hour"
     input_types = [ColumnSchema(logical_type=Datetime)]
     return_type = ColumnSchema(
-        logical_type=Ordinal(order=list(range(24))), semantic_tags={"category"}
+        logical_type=Ordinal(order=list(range(24))),
+        semantic_tags={"category"},
     )
     compatibility = [Library.PANDAS, Library.DASK, Library.SPARK]
     description_template = "the hour value of {}"
@@ -331,6 +338,42 @@ class IsLeapYear(TransformPrimitive):
         return is_leap_year
 
 
+class IsLunchTime(TransformPrimitive):
+    """Determines if a datetime falls during configurable lunch hour, on a 24-hour clock.
+
+    Args:
+        lunch_hour (int): Hour when lunch is taken. Must adhere to 24-hour clock. Defaults to 12.
+
+    Examples:
+        >>> from datetime import datetime
+        >>> dates = [datetime(2022, 6, 21, 12, 3, 3),
+        ...          datetime(2019, 1, 3, 4, 4, 4),
+        ...          datetime(2022, 1, 1, 11, 1, 2),
+        ...          np.nan]
+        >>> is_lunch_time = IsLunchTime()
+        >>> is_lunch_time(dates).tolist()
+        [True, False, False, False]
+        >>> is_lunch_time = IsLunchTime(11)
+        >>> is_lunch_time(dates).tolist()
+        [False, False, True, False]
+    """
+
+    name = "is_lunch_time"
+    input_types = [ColumnSchema(logical_type=Datetime)]
+    return_type = ColumnSchema(logical_type=BooleanNullable)
+    compatibility = [Library.PANDAS, Library.DASK, Library.SPARK]
+    description_template = "whether {} falls during lunch time"
+
+    def __init__(self, lunch_hour=12):
+        self.lunch_hour = lunch_hour
+
+    def get_function(self):
+        def is_lunch_time(vals):
+            return vals.dt.hour == self.lunch_hour
+
+        return is_lunch_time
+
+
 class IsMonthEnd(TransformPrimitive):
     """Determines the is_month_end attribute of a datetime column.
 
@@ -459,6 +502,44 @@ class IsWeekend(TransformPrimitive):
         return is_weekend
 
 
+class IsWorkingHours(TransformPrimitive):
+    """Determines if a datetime falls during working hours on a 24-hour clock. Can configure start_hour and end_hour.
+
+    Args:
+        start_hour (int): Start hour of workday. Must adhere to 24-hour clock. Default is 8 (8am).
+        end_hour (int): End hour of workday. Must adhere to 24-hour clock. Default is 18 (6pm).
+
+    Examples:
+        >>> from datetime import datetime
+        >>> dates = [datetime(2022, 6, 21, 16, 3, 3),
+        ...          datetime(2019, 1, 3, 4, 4, 4),
+        ...          datetime(2022, 1, 1, 12, 1, 2),
+        ...          np.nan]
+        >>> is_working_hour = IsWorkingHours()
+        >>> is_working_hour(dates).tolist()
+        [True, False, True, False]
+        >>> is_working_hour = IsWorkingHours(15, 17)
+        >>> is_working_hour(dates).tolist()
+        [True, False, False, False]
+    """
+
+    name = "is_working_hours"
+    input_types = [ColumnSchema(logical_type=Datetime)]
+    return_type = ColumnSchema(logical_type=BooleanNullable)
+    compatibility = [Library.PANDAS, Library.DASK, Library.SPARK]
+    description_template = "whether {} falls during working hours"
+
+    def __init__(self, start_hour=8, end_hour=18):
+        self.start_hour = start_hour
+        self.end_hour = end_hour
+
+    def get_function(self):
+        def is_working_hours(vals):
+            return (vals.dt.hour >= self.start_hour) & (vals.dt.hour <= self.end_hour)
+
+        return is_working_hours
+
+
 class IsYearEnd(TransformPrimitive):
     """Determines if a date falls on the end of a year.
 
@@ -529,7 +610,8 @@ class Minute(TransformPrimitive):
     name = "minute"
     input_types = [ColumnSchema(logical_type=Datetime)]
     return_type = ColumnSchema(
-        logical_type=Ordinal(order=list(range(60))), semantic_tags={"category"}
+        logical_type=Ordinal(order=list(range(60))),
+        semantic_tags={"category"},
     )
     compatibility = [Library.PANDAS, Library.DASK, Library.SPARK]
     description_template = "the minutes value of {}"
@@ -557,7 +639,8 @@ class Month(TransformPrimitive):
     name = "month"
     input_types = [ColumnSchema(logical_type=Datetime)]
     return_type = ColumnSchema(
-        logical_type=Ordinal(order=list(range(1, 13))), semantic_tags={"category"}
+        logical_type=Ordinal(order=list(range(1, 13))),
+        semantic_tags={"category"},
     )
     compatibility = [Library.PANDAS, Library.DASK, Library.SPARK]
     description_template = "the month of {}"
@@ -648,7 +731,8 @@ class Quarter(TransformPrimitive):
     name = "quarter"
     input_types = [ColumnSchema(logical_type=Datetime)]
     return_type = ColumnSchema(
-        logical_type=Ordinal(order=list(range(1, 5))), semantic_tags={"category"}
+        logical_type=Ordinal(order=list(range(1, 5))),
+        semantic_tags={"category"},
     )
     compatibility = [Library.PANDAS, Library.DASK, Library.SPARK]
     description_template = "the quarter that describes {}"
@@ -676,7 +760,8 @@ class Second(TransformPrimitive):
     name = "second"
     input_types = [ColumnSchema(logical_type=Datetime)]
     return_type = ColumnSchema(
-        logical_type=Ordinal(order=list(range(60))), semantic_tags={"category"}
+        logical_type=Ordinal(order=list(range(60))),
+        semantic_tags={"category"},
     )
     compatibility = [Library.PANDAS, Library.DASK, Library.SPARK]
     description_template = "the seconds value of {}"
@@ -773,7 +858,8 @@ class TimeSincePrevious(TransformPrimitive):
     def get_function(self):
         def pd_diff(values):
             return convert_time_units(
-                values.diff().apply(lambda x: x.total_seconds()), self.unit
+                values.diff().apply(lambda x: x.total_seconds()),
+                self.unit,
             )
 
         return pd_diff
@@ -800,7 +886,8 @@ class Week(TransformPrimitive):
     name = "week"
     input_types = [ColumnSchema(logical_type=Datetime)]
     return_type = ColumnSchema(
-        logical_type=Ordinal(order=list(range(1, 54))), semantic_tags={"category"}
+        logical_type=Ordinal(order=list(range(1, 54))),
+        semantic_tags={"category"},
     )
     compatibility = [Library.PANDAS, Library.DASK, Library.SPARK]
     description_template = "the week of the year of {}"
@@ -835,7 +922,8 @@ class Weekday(TransformPrimitive):
     name = "weekday"
     input_types = [ColumnSchema(logical_type=Datetime)]
     return_type = ColumnSchema(
-        logical_type=Ordinal(order=list(range(7))), semantic_tags={"category"}
+        logical_type=Ordinal(order=list(range(7))),
+        semantic_tags={"category"},
     )
     compatibility = [Library.PANDAS, Library.DASK, Library.SPARK]
     description_template = "the day of the week of {}"
@@ -863,7 +951,8 @@ class Year(TransformPrimitive):
     name = "year"
     input_types = [ColumnSchema(logical_type=Datetime)]
     return_type = ColumnSchema(
-        logical_type=Ordinal(order=list(range(1, 3000))), semantic_tags={"category"}
+        logical_type=Ordinal(order=list(range(1, 3000))),
+        semantic_tags={"category"},
     )
     compatibility = [Library.PANDAS, Library.DASK, Library.SPARK]
     description_template = "the year of {}"
@@ -913,7 +1002,8 @@ class IsFederalHoliday(TransformPrimitive):
     def get_function(self):
         def is_federal_holiday(x):
             holidays_df = pd.DataFrame(
-                sorted(self.federal_holidays.items()), columns=["dates", "names"]
+                sorted(self.federal_holidays.items()),
+                columns=["dates", "names"],
             )
             is_holiday = x.dt.normalize().isin(holidays_df.dates)
             if x.isnull().values.any():
