@@ -1,5 +1,6 @@
 from unittest.mock import patch
 
+import numpy as np
 import pandas as pd
 import pytest
 
@@ -9,8 +10,9 @@ from featuretools.primitives import (
     RollingMean,
     RollingMin,
     RollingSTD,
+    RollingTrend,
+    roll_series_with_gap,
 )
-from featuretools.primitives.utils import _roll_series_with_gap
 from featuretools.tests.primitive_tests.utils import get_number_from_offset
 
 
@@ -29,7 +31,7 @@ def test_rolling_max(min_periods, window_length, gap, rolling_series_pd):
     window_length_num = get_number_from_offset(window_length)
     # Since we're using a uniform series we can check correctness using numeric parameters
     expected_vals = (
-        _roll_series_with_gap(
+        roll_series_with_gap(
             rolling_series_pd, window_length_num, gap=gap_num, min_periods=min_periods
         )
         .max()
@@ -68,7 +70,7 @@ def test_rolling_min(min_periods, window_length, gap, rolling_series_pd):
 
     # Since we're using a uniform series we can check correctness using numeric parameters
     expected_vals = (
-        _roll_series_with_gap(
+        roll_series_with_gap(
             rolling_series_pd, window_length_num, gap=gap_num, min_periods=min_periods
         )
         .min()
@@ -107,7 +109,7 @@ def test_rolling_mean(min_periods, window_length, gap, rolling_series_pd):
 
     # Since we're using a uniform series we can check correctness using numeric parameters
     expected_vals = (
-        _roll_series_with_gap(
+        roll_series_with_gap(
             rolling_series_pd, window_length_num, gap=gap_num, min_periods=min_periods
         )
         .mean()
@@ -146,7 +148,7 @@ def test_rolling_std(min_periods, window_length, gap, rolling_series_pd):
 
     # Since we're using a uniform series we can check correctness using numeric parameters
     expected_vals = (
-        _roll_series_with_gap(
+        roll_series_with_gap(
             rolling_series_pd, window_length_num, gap=gap_num, min_periods=min_periods
         )
         .std()
@@ -188,7 +190,7 @@ def test_rolling_count(window_length, gap, rolling_series_pd):
     window_length_num = get_number_from_offset(window_length)
 
     expected_vals = (
-        _roll_series_with_gap(
+        roll_series_with_gap(
             rolling_series_pd,
             window_length_num,
             gap=gap_num,
@@ -207,7 +209,7 @@ def test_rolling_count(window_length, gap, rolling_series_pd):
 
     num_nans = gap_num + window_length_num - 1
     assert actual_vals.isna().sum() == num_nans
-    # RollingCount will not match the exact _roll_series_with_gap call,
+    # RollingCount will not match the exact roll_series_with_gap call,
     # because it handles the min_periods difference within the primitive
     pd.testing.assert_series_equal(
         pd.Series(expected_vals).iloc[num_nans:], actual_vals.iloc[num_nans:]
@@ -249,7 +251,72 @@ def test_rolling_count_with_no_gap(
 
 
 @pytest.mark.parametrize(
-    "primitive", [RollingCount, RollingMax, RollingMin, RollingMean]
+    "window_length, gap, expected_vals",
+    [
+        (3, 0, [np.nan, np.nan, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1]),
+        (
+            4,
+            1,
+            [np.nan, np.nan, np.nan, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1],
+        ),
+        (
+            "5d",
+            "7d",
+            [
+                np.nan,
+                np.nan,
+                np.nan,
+                np.nan,
+                np.nan,
+                np.nan,
+                np.nan,
+                np.nan,
+                np.nan,
+                1,
+                1,
+                1,
+                1,
+                1,
+                1,
+                1,
+                1,
+                1,
+                1,
+                1,
+            ],
+        ),
+        (
+            "5d",
+            "0d",
+            [np.nan, np.nan, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1],
+        ),
+    ],
+)
+def test_rolling_trend(window_length, gap, expected_vals, rolling_series_pd):
+    primitive_instance = RollingTrend(window_length=window_length, gap=gap)
+
+    actual_vals = primitive_instance(rolling_series_pd.index, rolling_series_pd.values)
+
+    pd.testing.assert_series_equal(pd.Series(expected_vals), pd.Series(actual_vals))
+
+
+def test_rolling_trend_window_length_less_than_three(rolling_series_pd):
+    primitive_instance = RollingTrend(window_length=2)
+
+    vals = primitive_instance(rolling_series_pd.index, rolling_series_pd.values)
+
+    for v in vals:
+        assert np.isnan(v)
+
+
+@pytest.mark.parametrize(
+    "primitive",
+    [
+        RollingCount,
+        RollingMax,
+        RollingMin,
+        RollingMean,
+    ],
 )
 def test_rolling_primitives_non_uniform(primitive):
     # When the data isn't uniform, this impacts the number of values in each rolling window
@@ -309,12 +376,38 @@ def test_rolling_std_non_uniform():
     pd.testing.assert_series_equal(rolled_series, expected_series)
 
 
+def test_rolling_trend_non_uniform():
+    datetimes = (
+        list(pd.date_range(start="2017-01-01", freq="1d", periods=3))
+        + list(pd.date_range(start="2017-01-10", freq="2d", periods=4))
+        + list(pd.date_range(start="2017-01-22", freq="1d", periods=7))
+    )
+    no_freq_series = pd.Series(range(len(datetimes)), index=datetimes)
+    expected_series = pd.Series(
+        [None, None, None]
+        + [None, None, None, None]
+        + [
+            None,
+            None,
+            None,
+            1.0,
+            1.0,
+            1.0,
+            1.0,
+        ]
+    )
+    primitive_instance = RollingTrend(window_length="3d", gap="1d")
+    rolled_series = pd.Series(
+        primitive_instance(no_freq_series.index, pd.Series(no_freq_series.values))
+    )
+    pd.testing.assert_series_equal(rolled_series, expected_series)
+
+
 @pytest.mark.parametrize(
-    "primitive", [RollingCount, RollingMax, RollingMin, RollingMean, RollingSTD]
-)
-@patch(
-    "featuretools.primitives.rolling_transform_primitive._apply_roll_with_offset_gap"
+    "primitive",
+    [RollingCount, RollingMax, RollingMin, RollingMean, RollingSTD, RollingTrend],
 )
+@patch("featuretools.primitives.rolling_transform_primitive.apply_roll_with_offset_gap")
 def test_no_call_to_apply_roll_with_offset_gap_with_numeric(
     mock_apply_roll, primitive, rolling_series_pd
 ):
