@@ -11,10 +11,12 @@ from featuretools.primitives import (
     EmailAddressToDomain,
     IsFreeEmailDomain,
     IsLeapYear,
+    IsLunchTime,
     IsMonthEnd,
     IsMonthStart,
     IsQuarterEnd,
     IsQuarterStart,
+    IsWorkingHours,
     IsYearEnd,
     IsYearStart,
     NumericLag,
@@ -37,7 +39,7 @@ def test_time_since():
             datetime(2019, 3, 1, 0, 0, 0, 1),
             datetime(2019, 3, 1, 0, 0, 1, 0),
             datetime(2019, 3, 1, 0, 2, 0, 0),
-        ]
+        ],
     )
     cutoff_time = datetime(2019, 3, 1, 0, 0, 0, 0)
     values = time_since(array=times, time=cutoff_time)
@@ -65,7 +67,7 @@ def test_time_since():
             datetime(2019, 3, 1, 0, 0, 0, 1),
             datetime(2020, 3, 1, 0, 0, 1, 0),
             datetime(2017, 3, 1, 0, 0, 0, 0),
-        ]
+        ],
     )
 
     time_since = TimeSince(unit="Years")
@@ -126,7 +128,7 @@ def test_day_of_year():
 def test_days_in_month():
     dim = DaysInMonth()
     dates = pd.Series(
-        [datetime(2010, 1, 1), datetime(2019, 2, 1), np.nan, datetime(2020, 2, 1)]
+        [datetime(2010, 1, 1), datetime(2019, 2, 1), np.nan, datetime(2020, 2, 1)],
     )
     days_in_month = dim(dates)
     correct_days = [31, 28, np.nan, 29]
@@ -144,7 +146,7 @@ def test_is_leap_year():
 def test_is_month_end():
     ime = IsMonthEnd()
     dates = pd.Series(
-        [datetime(2019, 3, 1), datetime(2021, 2, 28), datetime(2020, 2, 29)]
+        [datetime(2019, 3, 1), datetime(2021, 2, 28), datetime(2020, 2, 29)],
     )
     ime_bools = ime(dates)
     correct_bools = [False, True, True]
@@ -154,7 +156,7 @@ def test_is_month_end():
 def test_is_month_start():
     ims = IsMonthStart()
     dates = pd.Series(
-        [datetime(2019, 3, 1), datetime(2020, 2, 28), datetime(2020, 2, 29)]
+        [datetime(2019, 3, 1), datetime(2020, 2, 28), datetime(2020, 2, 29)],
     )
     ims_bools = ims(dates)
     correct_bools = [True, False, False]
@@ -177,6 +179,64 @@ def test_is_quarter_start():
     np.testing.assert_array_equal(iqs_bools, correct_bools)
 
 
+def test_is_lunch_time_default():
+    is_lunch_time = IsLunchTime()
+    dates = pd.Series(
+        [
+            datetime(2022, 6, 26, 12, 12, 12),
+            datetime(2022, 6, 28, 12, 3, 4),
+            datetime(2022, 6, 28, 11, 3, 4),
+            np.nan,
+        ],
+    )
+    actual = is_lunch_time(dates)
+    expected = [True, True, False, False]
+    np.testing.assert_array_equal(actual, expected)
+
+
+def test_is_lunch_time_configurable():
+    is_lunch_time = IsLunchTime(14)
+    dates = pd.Series(
+        [
+            datetime(2022, 6, 26, 12, 12, 12),
+            datetime(2022, 6, 28, 14, 3, 4),
+            datetime(2022, 6, 28, 11, 3, 4),
+            np.nan,
+        ],
+    )
+    actual = is_lunch_time(dates)
+    expected = [False, True, False, False]
+    np.testing.assert_array_equal(actual, expected)
+
+
+def test_is_working_hours_standard_hours():
+    is_working_hours = IsWorkingHours()
+    dates = pd.Series(
+        [
+            datetime(2022, 6, 21, 16, 3, 3),
+            datetime(2019, 1, 3, 4, 4, 4),
+            datetime(2022, 1, 1, 12, 1, 2),
+        ],
+    )
+    actual = is_working_hours(dates).tolist()
+    expected = [True, False, True]
+    np.testing.assert_array_equal(actual, expected)
+
+
+def test_is_working_hours_configured_hours():
+    is_working_hours = IsWorkingHours(15, 18)
+    dates = pd.Series(
+        [
+            datetime(2022, 6, 21, 16, 3, 3),
+            datetime(2022, 6, 26, 14, 4, 4),
+            datetime(2022, 1, 1, 12, 1, 2),
+        ],
+    )
+    answer = is_working_hours(dates).tolist()
+    expected = [True, False, False]
+    np.testing.assert_array_equal(answer, expected)
+
+
 def test_part_of_day():
     pod = PartOfDay()
     dates = pd.Series(
@@ -191,7 +251,7 @@ def test_part_of_day():
             datetime(2020, 3, 4, 17, 2, 3),
             datetime(2020, 2, 2, 20, 2, 2),
             np.nan,
-        ]
+        ],
     )
     actual = pod(dates)
     expected = pd.Series(
@@ -206,7 +266,7 @@ def test_part_of_day():
             "evening",
             "night",
             np.nan,
-        ]
+        ],
     )
     pd.testing.assert_series_equal(expected, actual)
 
@@ -235,7 +295,7 @@ def test_quarter_regular():
             pd.to_datetime("2018-04-01"),
             pd.to_datetime("2018-07-01"),
             pd.to_datetime("2018-10-01"),
-        ]
+        ],
     )
     answer = q(array)
     correct_answer = pd.Series([1, 2, 3, 4])
@@ -250,7 +310,7 @@ def test_quarter_leap_year():
             pd.to_datetime("2018-04-01"),
             pd.to_datetime("2018-07-01"),
             pd.to_datetime("2018-10-01"),
-        ]
+        ],
     )
     answer = q(array)
     correct_answer = pd.Series([1, 2, 3, 4])
@@ -265,7 +325,7 @@ def test_quarter_nan_and_nat_input():
             np.nan,
             np.datetime64("NaT"),
             pd.to_datetime("2018-10-01"),
-        ]
+        ],
     )
     answer = q(array)
     correct_answer = pd.Series([1, np.nan, np.nan, 4])
@@ -280,7 +340,7 @@ def test_quarter_year_before_1970():
             pd.to_datetime("1950-04-01"),
             pd.to_datetime("1874-07-01"),
             pd.to_datetime("2018-10-01"),
-        ]
+        ],
     )
     answer = q(array)
     correct_answer = pd.Series([1, 2, 3, 4])
@@ -295,7 +355,7 @@ def test_quarter_year_after_2038():
             pd.to_datetime("2050-04-01"),
             pd.to_datetime("2174-07-01"),
             pd.to_datetime("2018-10-01"),
-        ]
+        ],
     )
     answer = q(array)
     correct_answer = pd.Series([1, 2, 3, 4])
@@ -339,7 +399,7 @@ def test_url_to_domain_urls():
             "facebook.com",
             "https://www.compzets.net?asd=10",
             "http://www.featuretools.org",
-        ]
+        ],
     )
     correct_urls = [
         "play.google.com",
@@ -370,8 +430,8 @@ def test_url_to_domain_long_url():
                         6%7C6%7C6%7C6%7C5%7C5&chdl=android%7Cjava%7Cstack-trace%7Cbro \
                         adcastreceiver%7Candroid-ndk%7Cuser-agent%7Candroid-webview%7 \
                         Cwebview%7Cbackground%7Cmultithreading%7Candroid-source%7Csms \
-                        %7Cadb%7Csollections%7Cactivity|Chart"
-        ]
+                        %7Cadb%7Csollections%7Cactivity|Chart",
+        ],
     )
     correct_urls = ["chart.apis.google.com"]
     results = url_to_domain(urls)
@@ -401,7 +461,7 @@ def test_url_to_protocol_urls():
             "https://www.compzets.net?asd=10",
             "http://www.featuretools.org",
             "https://featuretools.com",
-        ]
+        ],
     )
     correct_urls = pd.Series(
         [
@@ -416,7 +476,7 @@ def test_url_to_protocol_urls():
             "https",
             "http",
             "https",
-        ]
+        ],
     )
     results = url_to_protocol(urls)
     pd.testing.assert_series_equal(results, correct_urls)
@@ -433,8 +493,8 @@ def test_url_to_protocol_long_url():
                         6%7C6%7C6%7C6%7C5%7C5&chdl=android%7Cjava%7Cstack-trace%7Cbro \
                         adcastreceiver%7Candroid-ndk%7Cuser-agent%7Candroid-webview%7 \
                         Cwebview%7Cbackground%7Cmultithreading%7Candroid-source%7Csms \
-                        %7Cadb%7Csollections%7Cactivity|Chart"
-        ]
+                        %7Cadb%7Csollections%7Cactivity|Chart",
+        ],
     )
     correct_urls = ["http"]
     results = url_to_protocol(urls)
@@ -466,7 +526,7 @@ def test_url_to_tld_urls():
             "https://www.compzets.net?asd=10",
             "http://www.featuretools.org",
             "featuretools.org",
-        ]
+        ],
     )
     correct_urls = [
         "com",
@@ -497,8 +557,8 @@ def test_url_to_tld_long_url():
                         6%7C6%7C6%7C6%7C5%7C5&chdl=android%7Cjava%7Cstack-trace%7Cbro \
                         adcastreceiver%7Candroid-ndk%7Cuser-agent%7Candroid-webview%7 \
                         Cwebview%7Cbackground%7Cmultithreading%7Candroid-source%7Csms \
-                        %7Cadb%7Csollections%7Cactivity|Chart"
-        ]
+                        %7Cadb%7Csollections%7Cactivity|Chart",
+        ],
     )
     correct_urls = ["com"]
     np.testing.assert_array_equal(url_to_tld(urls), correct_urls)
@@ -507,7 +567,8 @@ def test_url_to_tld_long_url():
 def test_url_to_tld_nan():
     url_to_tld = URLToTLD()
     urls = pd.Series(
-        ["www.featuretools.com", np.nan, "featuretools", ""], dtype="object"
+        ["www.featuretools.com", np.nan, "featuretools", ""],
+        dtype="object",
     )
     correct_urls = pd.Series(["com", np.nan, np.nan, np.nan], dtype="object")
     results = url_to_tld(urls)
@@ -522,7 +583,7 @@ def test_is_free_email_domain_valid_addresses():
             "name@featuretools.com",
             "nobody@yahoo.com",
             "free@gmail.com",
-        ]
+        ],
     )
     answers = pd.Series(is_free_email_domain(array))
     correct_answers = pd.Series([True, False, True, True])
@@ -537,7 +598,7 @@ def test_is_free_email_domain_valid_addresses_whitespace():
             " name@featuretools.com",
             "nobody@yahoo.com ",
             " free@gmail.com ",
-        ]
+        ],
     )
     answers = pd.Series(is_free_email_domain(array))
     correct_answers = pd.Series([True, False, True, True])
@@ -579,7 +640,7 @@ def test_is_free_email_domain_invalid_email():
             1234,
             1.23,
             True,
-        ]
+        ],
     )
     answers = pd.Series(is_free_email_domain(array))
     correct_answers = pd.Series([np.nan, np.nan, False, True, np.nan, np.nan, np.nan])
@@ -602,11 +663,11 @@ def test_email_address_to_domain_valid_addresses():
             "name@featuretools.com",
             "nobody@yahoo.com",
             "free@gmail.com",
-        ]
+        ],
     )
     answers = pd.Series(email_address_to_domain(array))
     correct_answers = pd.Series(
-        ["hotmail.com", "featuretools.com", "yahoo.com", "gmail.com"]
+        ["hotmail.com", "featuretools.com", "yahoo.com", "gmail.com"],
     )
     pd.testing.assert_series_equal(answers, correct_answers)
 
@@ -619,11 +680,11 @@ def test_email_address_to_domain_valid_addresses_whitespace():
             " name@featuretools.com",
             "nobody@yahoo.com ",
             " free@gmail.com ",
-        ]
+        ],
     )
     answers = pd.Series(email_address_to_domain(array))
     correct_answers = pd.Series(
-        ["hotmail.com", "featuretools.com", "yahoo.com", "gmail.com"]
+        ["hotmail.com", "featuretools.com", "yahoo.com", "gmail.com"],
     )
     pd.testing.assert_series_equal(answers, correct_answers)
 
@@ -663,11 +724,11 @@ def test_email_address_to_domain_invalid_email():
             1234,
             1.23,
             True,
-        ]
+        ],
     )
     answers = pd.Series(email_address_to_domain(array))
     correct_answers = pd.Series(
-        [np.nan, np.nan, "featuretools.com", "yahoo.com", np.nan, np.nan, np.nan]
+        [np.nan, np.nan, "featuretools.com", "yahoo.com", np.nan, np.nan, np.nan],
     )
     pd.testing.assert_series_equal(answers, correct_answers)
 
