@@ -3,8 +3,13 @@ import pandas as pd
 import pytest
 from woodwork.logical_types import NaturalLanguage
 
-import featuretools as ft
-from featuretools import Feature
+from featuretools import EntitySet, Feature, dfs
+from featuretools.selection import (
+    remove_highly_correlated_features,
+    remove_highly_null_features,
+    remove_low_information_features,
+    remove_single_value_features,
+)
 from featuretools.tests.testing_utils import make_ecommerce_entityset
 
 
@@ -19,7 +24,7 @@ def feature_matrix():
             "many_value": [1, 2, 3],
             "dup_value": [1, 1, 2],
             "one_value": [1, 1, 1],
-        }
+        },
     )
     return feature_matrix
 
@@ -32,7 +37,7 @@ def test_es(pd_es, feature_matrix):
 
 # remove low information features not supported in Dask
 def test_remove_low_information_feature_names(feature_matrix):
-    feature_matrix = ft.selection.remove_low_information_features(feature_matrix)
+    feature_matrix = remove_low_information_features(feature_matrix)
     assert feature_matrix.shape == (3, 5)
     assert "one_value" not in feature_matrix.columns
     assert "all_null" not in feature_matrix.columns
@@ -41,9 +46,7 @@ def test_remove_low_information_feature_names(feature_matrix):
 # remove low information features not supported in Dask
 def test_remove_low_information_features(test_es, feature_matrix):
     features = [Feature(test_es["test"].ww[col]) for col in test_es["test"].columns]
-    feature_matrix, features = ft.selection.remove_low_information_features(
-        feature_matrix, features
-    )
+    feature_matrix, features = remove_low_information_features(feature_matrix, features)
     assert feature_matrix.shape == (3, 5)
     assert len(features) == 5
     for f in features:
@@ -60,14 +63,14 @@ def test_remove_highly_null_features():
             "all_nulls": [None, None, None, None],
             "quarter": ["a", "b", None, "c"],
             "vals": [True, True, False, False],
-        }
+        },
     )
 
-    es = ft.EntitySet("data", {"nulls": (nulls_df, "id")})
+    es = EntitySet("data", {"nulls": (nulls_df, "id")})
     es["nulls"].ww.set_types(
-        logical_types={"all_nulls": "categorical", "quarter": "categorical"}
+        logical_types={"all_nulls": "categorical", "quarter": "categorical"},
     )
-    fm, features = ft.dfs(
+    fm, features = dfs(
         entityset=es,
         target_dataframe_name="nulls",
         trans_primitives=["is_null"],
@@ -78,28 +81,28 @@ def test_remove_highly_null_features():
         ValueError,
         match="pct_null_threshold must be a float between 0 and 1, inclusive.",
     ):
-        ft.selection.remove_highly_null_features(fm, pct_null_threshold=1.1)
+        remove_highly_null_features(fm, pct_null_threshold=1.1)
 
     with pytest.raises(
         ValueError,
         match="pct_null_threshold must be a float between 0 and 1, inclusive.",
     ):
-        ft.selection.remove_highly_null_features(fm, pct_null_threshold=-0.1)
+        remove_highly_null_features(fm, pct_null_threshold=-0.1)
 
-    no_thresh = ft.selection.remove_highly_null_features(fm)
+    no_thresh = remove_highly_null_features(fm)
     no_thresh_cols = set(no_thresh.columns)
     diff = set(fm.columns) - no_thresh_cols
     assert len(diff) == 1
     assert "all_nulls" not in no_thresh_cols
 
-    half = ft.selection.remove_highly_null_features(fm, pct_null_threshold=0.5)
+    half = remove_highly_null_features(fm, pct_null_threshold=0.5)
     half_cols = set(half.columns)
     diff = set(fm.columns) - half_cols
     assert len(diff) == 2
     assert "all_nulls" not in half_cols
     assert "half_nulls" not in half_cols
 
-    no_tolerance = ft.selection.remove_highly_null_features(fm, pct_null_threshold=0)
+    no_tolerance = remove_highly_null_features(fm, pct_null_threshold=0)
     no_tolerance_cols = set(no_tolerance.columns)
     diff = set(fm.columns) - no_tolerance_cols
     assert len(diff) == 3
@@ -110,7 +113,7 @@ def test_remove_highly_null_features():
     (
         with_features_param,
         with_features_param_features,
-    ) = ft.selection.remove_highly_null_features(fm, features)
+    ) = remove_highly_null_features(fm, features)
     assert len(with_features_param_features) == len(no_thresh.columns)
     for i in range(len(with_features_param_features)):
         assert with_features_param_features[i].get_name() == no_thresh.columns[i]
@@ -127,34 +130,34 @@ def test_remove_single_value_features():
             "all_categorical": ["a", "a", "a", "a"],
             "all_bools": [True, True, True, True],
             "diff_vals": ["hi", "bye", "bye", "hi"],
-        }
+        },
     )
 
-    es = ft.EntitySet("data", {"single_vals": (same_vals_df, "id")})
+    es = EntitySet("data", {"single_vals": (same_vals_df, "id")})
     es["single_vals"].ww.set_types(
         logical_types={
             "all_nulls": "categorical",
             "all_categorical": "categorical",
             "diff_vals": "categorical",
-        }
+        },
     )
-    fm, features = ft.dfs(
+    fm, features = dfs(
         entityset=es,
         target_dataframe_name="single_vals",
         trans_primitives=["is_null"],
         max_depth=2,
     )
 
-    no_params, no_params_features = ft.selection.remove_single_value_features(
-        fm, features
-    )
+    no_params, no_params_features = remove_single_value_features(fm, features)
     no_params_cols = set(no_params.columns)
     assert len(no_params_features) == 2
     assert "IS_NULL(with_nan)" in no_params_cols
     assert "diff_vals" in no_params_cols
 
-    nan_as_value, nan_as_value_features = ft.selection.remove_single_value_features(
-        fm, features, count_nan_as_value=True
+    nan_as_value, nan_as_value_features = remove_single_value_features(
+        fm,
+        features,
+        count_nan_as_value=True,
     )
     nan_cols = set(nan_as_value.columns)
     assert len(nan_as_value_features) == 3
@@ -162,7 +165,7 @@ def test_remove_single_value_features():
     assert "diff_vals" in nan_cols
     assert "with_nan" in nan_cols
 
-    without_features_param = ft.selection.remove_single_value_features(fm)
+    without_features_param = remove_single_value_features(fm)
     assert len(no_params.columns) == len(without_features_param.columns)
     for i in range(len(no_params.columns)):
         assert no_params.columns[i] == without_features_param.columns[i]
@@ -178,13 +181,14 @@ def test_remove_highly_correlated_features():
             "corr_words": [4, 24, 7, 3],
             "corr_1": [99, 88, 77, 33],
             "corr_2": [99, 88, 77, 33],
-        }
+        },
     )
 
-    es = ft.EntitySet(
-        "data", {"correlated": (correlated_df, "id", None, {"words": NaturalLanguage})}
+    es = EntitySet(
+        "data",
+        {"correlated": (correlated_df, "id", None, {"words": NaturalLanguage})},
     )
-    fm, _ = ft.dfs(
+    fm, _ = dfs(
         entityset=es,
         target_dataframe_name="correlated",
         trans_primitives=["num_characters"],
@@ -195,23 +199,23 @@ def test_remove_highly_correlated_features():
         ValueError,
         match="pct_corr_threshold must be a float between 0 and 1, inclusive.",
     ):
-        ft.selection.remove_highly_correlated_features(fm, pct_corr_threshold=1.1)
+        remove_highly_correlated_features(fm, pct_corr_threshold=1.1)
 
     with pytest.raises(
         ValueError,
         match="pct_corr_threshold must be a float between 0 and 1, inclusive.",
     ):
-        ft.selection.remove_highly_correlated_features(fm, pct_corr_threshold=-0.1)
+        remove_highly_correlated_features(fm, pct_corr_threshold=-0.1)
 
     with pytest.raises(
-        AssertionError, match="feature named not_a_feature is not in feature matrix"
+        AssertionError,
+        match="feature named not_a_feature is not in feature matrix",
     ):
-        ft.selection.remove_highly_correlated_features(
-            fm, features_to_check=["not_a_feature"]
-        )
+        remove_highly_correlated_features(fm, features_to_check=["not_a_feature"])
 
-    to_check = ft.selection.remove_highly_correlated_features(
-        fm, features_to_check=["corr_words", "NUM_CHARACTERS(words)", "diff_ints"]
+    to_check = remove_highly_correlated_features(
+        fm,
+        features_to_check=["corr_words", "NUM_CHARACTERS(words)", "diff_ints"],
     )
     to_check_columns = set(to_check.columns)
     assert len(to_check_columns) == 4
@@ -219,8 +223,9 @@ def test_remove_highly_correlated_features():
     assert "corr_1" in to_check_columns
     assert "corr_2" in to_check_columns
 
-    to_keep = ft.selection.remove_highly_correlated_features(
-        fm, features_to_keep=["NUM_CHARACTERS(words)"]
+    to_keep = remove_highly_correlated_features(
+        fm,
+        features_to_keep=["NUM_CHARACTERS(words)"],
     )
     to_keep_names = set(to_keep.columns)
     assert len(to_keep_names) == 4
@@ -228,14 +233,12 @@ def test_remove_highly_correlated_features():
     assert "NUM_CHARACTERS(words)" in to_keep_names
     assert "corr_2" not in to_keep_names
 
-    new_fm = ft.selection.remove_highly_correlated_features(fm)
+    new_fm = remove_highly_correlated_features(fm)
     assert len(new_fm.columns) == 3
     assert "corr_2" not in new_fm.columns
     assert "NUM_CHARACTERS(words)" not in new_fm.columns
 
-    diff_threshold = ft.selection.remove_highly_correlated_features(
-        fm, pct_corr_threshold=0.8
-    )
+    diff_threshold = remove_highly_correlated_features(fm, pct_corr_threshold=0.8)
     diff_threshold_cols = diff_threshold.columns
     assert len(diff_threshold_cols) == 2
     assert "corr_words" in diff_threshold_cols
@@ -251,13 +254,14 @@ def test_remove_highly_correlated_features_init_woodwork():
             "corr_words": [4, 24, 7, 3],
             "corr_1": [99, 88, 77, 33],
             "corr_2": [99, 88, 77, 33],
-        }
+        },
     )
 
-    es = ft.EntitySet(
-        "data", {"correlated": (correlated_df, "id", None, {"words": NaturalLanguage})}
+    es = EntitySet(
+        "data",
+        {"correlated": (correlated_df, "id", None, {"words": NaturalLanguage})},
     )
-    fm, _ = ft.dfs(
+    fm, _ = dfs(
         entityset=es,
         target_dataframe_name="correlated",
         trans_primitives=["num_characters"],
@@ -268,8 +272,8 @@ def test_remove_highly_correlated_features_init_woodwork():
     ww_fm = fm.copy()
     ww_fm.ww.init()
 
-    new_no_ww_fm = ft.selection.remove_highly_correlated_features(no_ww_fm)
-    new_ww_fm = ft.selection.remove_highly_correlated_features(ww_fm)
+    new_no_ww_fm = remove_highly_correlated_features(no_ww_fm)
+    new_ww_fm = remove_highly_correlated_features(ww_fm)
 
     pd.testing.assert_frame_equal(new_no_ww_fm, new_ww_fm)
 
@@ -282,7 +286,7 @@ def test_multi_output_selection():
             "first_id": [0, 1, 1, 3],
             "all_nulls": [None, None, None, None],
             "quarter": ["a", "b", None, "c"],
-        }
+        },
     )
 
     dataframes = {
@@ -291,12 +295,12 @@ def test_multi_output_selection():
     }
 
     relationships = [("first", "id", "second", "first_id")]
-    es = ft.EntitySet("data", dataframes, relationships=relationships)
+    es = EntitySet("data", dataframes, relationships=relationships)
     es["second"].ww.set_types(
-        logical_types={"all_nulls": "categorical", "quarter": "categorical"}
+        logical_types={"all_nulls": "categorical", "quarter": "categorical"},
     )
 
-    fm, features = ft.dfs(
+    fm, features = dfs(
         entityset=es,
         target_dataframe_name="first",
         trans_primitives=[],
@@ -304,15 +308,13 @@ def test_multi_output_selection():
         max_depth=2,
     )
 
-    multi_output, multi_output_features = ft.selection.remove_single_value_features(
-        fm, features
-    )
+    multi_output, multi_output_features = remove_single_value_features(fm, features)
     assert multi_output.columns == ["N_MOST_COMMON(second.quarter)[0]"]
     assert len(multi_output_features) == 1
     assert multi_output_features[0].get_name() == multi_output.columns[0]
 
     es = make_ecommerce_entityset()
-    fm, features = ft.dfs(
+    fm, features = dfs(
         entityset=es,
         target_dataframe_name="régions",
         trans_primitives=[],
@@ -320,9 +322,7 @@ def test_multi_output_selection():
         max_depth=2,
     )
 
-    matrix_with_slices, unsliced_features = ft.selection.remove_highly_null_features(
-        fm, features
-    )
+    matrix_with_slices, unsliced_features = remove_highly_null_features(fm, features)
     assert len(matrix_with_slices.columns) == 18
     assert len(unsliced_features) == 14
 
