@@ -1,9 +1,10 @@
 import dask.dataframe as dd
 import pandas as pd
 import pytest
-from woodwork import list_logical_types, list_semantic_tags
+from woodwork import list_logical_types as ww_list_logical_types
+from woodwork import list_semantic_tags as ww_list_semantic_tags
 
-import featuretools as ft
+from featuretools import list_logical_types, list_semantic_tags
 from featuretools.utils.gen_utils import (
     camel_and_title_to_snake,
     import_or_none,
@@ -60,14 +61,14 @@ def test_is_instance_none_module(df):
 
 
 def test_list_logical_types():
-    ft_ltypes = ft.list_logical_types()
-    ww_ltypes = list_logical_types()
+    ft_ltypes = list_logical_types()
+    ww_ltypes = ww_list_logical_types()
     assert ft_ltypes.equals(ww_ltypes)
 
 
 def test_list_semantic_tags():
-    ft_semantic_tags = ft.list_semantic_tags()
-    ww_semantic_tags = list_semantic_tags()
+    ft_semantic_tags = list_semantic_tags()
+    ww_semantic_tags = ww_list_semantic_tags()
     assert ft_semantic_tags.equals(ww_semantic_tags)
 
 
